import React from "react";
import ReactDOM from "react-dom";
import { PoolRebalance } from "../components/pool-rebalance";

ReactDOM.render(
  <PoolRebalance />,
  document.getElementById('pool-rebalance')
);
